[Lldb-commits] [lldb] [lldb][test] Add missing includes (PR #201794)

via lldb-commits lldb-commits at lists.llvm.org
Fri Jun 5 04:05:51 PDT 2026


https://github.com/paperchalice updated https://github.com/llvm/llvm-project/pull/201794

>From b22b67d9a5885c98272666ec2fe4238cf05184ca Mon Sep 17 00:00:00 2001
From: Raphael Isemann <rise at apple.com>
Date: Fri, 5 Jun 2026 10:18:45 +0100
Subject: [PATCH] [lldb][test] Add missing includes

These tests only compiled by accident because libc indirectly included
the needed headers.
---
 lldb/test/API/iohandler/sigint/cat.cpp             |  1 +
 .../breakpoint/TestDAP_breakpointLocations.py      | 14 +++++++-------
 lldb/test/API/tools/lldb-dap/breakpoint/main.cpp   |  1 +
 3 files changed, 9 insertions(+), 7 deletions(-)

diff --git a/lldb/test/API/iohandler/sigint/cat.cpp b/lldb/test/API/iohandler/sigint/cat.cpp
index 7e12cf7df7e58..368f5db75224c 100644
--- a/lldb/test/API/iohandler/sigint/cat.cpp
+++ b/lldb/test/API/iohandler/sigint/cat.cpp
@@ -1,3 +1,4 @@
+#include <cerrno>
 #include <cstdio>
 #include <string>
 #include <unistd.h>
diff --git a/lldb/test/API/tools/lldb-dap/breakpoint/main.cpp b/lldb/test/API/tools/lldb-dap/breakpoint/main.cpp
index 2206b07f19494..9788223d9d9b1 100644
--- a/lldb/test/API/tools/lldb-dap/breakpoint/main.cpp
+++ b/lldb/test/API/tools/lldb-dap/breakpoint/main.cpp
@@ -1,6 +1,7 @@
 #include <dlfcn.h>
 #include <stdexcept>
 #include <stdio.h>
+#include <stdlib.h>
 
 int twelve(int i) {
   return 12 + i; // break 12



More information about the lldb-commits mailing list
diff --git a/lldb/test/API/tools/lldb-dap/breakpoint/TestDAP_breakpointLocations.py b/lldb/test/API/tools/lldb-dap/breakpoint/TestDAP_breakpointLocations.py
index 1df5923b18b70..1fe5f8b9e2adc 100644
--- a/lldb/test/API/tools/lldb-dap/breakpoint/TestDAP_breakpointLocations.py
+++ b/lldb/test/API/tools/lldb-dap/breakpoint/TestDAP_breakpointLocations.py
@@ -76,14 +76,14 @@ def test_column_breakpoints(self):
         self.maxDiff = None
         self.assertTrue(response["success"])
         # On some systems, there is an additional breakpoint available
         # at line 41, column 3, i.e. at the end of the loop. To make this
         # test more portable, only check that all expected breakpoints are
         # presented, but also accept additional breakpoints.
         expected_breakpoints = [
-            {"column": 39, "line": 40},
-            {"column": 51, "line": 40},
-            {"column": 3, "line": 42},
-            {"column": 18, "line": 42},
+            {"column": 39, "line": loop_line},
+            {"column": 51, "line": loop_line},
+            {"column": 3, "line": loop_line + 2},
+            {"column": 18, "line": loop_line + 2},
         ]
         for bp in expected_breakpoints:
             self.assertIn(bp, response["body"]["breakpoints"])
@@ -76,14 +76,14 @@ def test_column_breakpoints(self):
         self.assertTrue(response["success"])
         # On some systems, there is an additional breakpoint available
-        # at line 41, column 3, i.e. at the end of the loop. To make this
-        # test more portable, only check that all expected breakpoints are
-        # presented, but also accept additional breakpoints.
+        # at loop_line + 1, column 3, i.e. at the end of the loop. To make
+        # this test more portable, only check that all expected breakpoints
+        # are presented, but also accept additional breakpoints.
         expected_breakpoints = [